@@ -116,6 +116,7 @@ my @rename_list = (
 "lib/libsupc++.a:#gcc_lib#/libsupcxx.a",
 "lib/libstdcxx.la:#gcc_lib#/libstdcxx.la",
 "lib/libstdcxx.a:#gcc_lib#/libstdcxx.a",
+"libstdcxx_a-gdb.py:#gcc_lib#/libstdcxx_a-gdb-py",
 "lib/libstdcxx.a-gdb.py:##libstdcxx_a-gdb.py",
 "lib/libgf95begin.a:#gcc_lib#/libgf95begin.a",
 "lib/libgfortran.a:#gcc_lib#/libgfortran.a",
@@ -123,6 +124,13 @@ my @rename_list = (
 "lib/libgfortran.la:#gcc_lib#/libgfortran.la",
 "lib/libobjc.a:#gcc_lib#/libobjc.a",
 "lib/libobjc.la:#gcc_lib#/libobjc.la",
+"lib/libquadmath.a:#gcc_lib#/libquadmath.a",
+"lib/libquadmath.la:#gcc_lib#/libquadmath.la",
+"lib/libssp.a:#gcc_lib#/libssp.a",
+"lib/libssp.la:#gcc_lib#/libssp.la",
+"lib/libssp_nonshared.a:#gcc_lib#/libssp_nonshared.a",
+"lib/libssp_nonshared.la:#gcc_lib#/libssp_nonshared.la",
+"lib/libgfortran.spec:#gcc_lib#/libgfortran.spec",
 "bin/g++.exe:##/gpp.exe",
 "bin/c++.exe:",
 "bin/djgpp-g++.exe:",
@@ -138,7 +146,6 @@ my @docfiles = (
 "fixincludes/README-fixinc", "fixincludes/README",
 "gcc/COPYING", "gcc/COPYING3", "gcc/ONEWS", "gcc/onews",
 "gcc/cp/NEWS",
-"gcc/objc/README",
 "libobjc/README", "libobjc/THREADS",
 "libstdc++-v3/README",
 );
