@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-archive=${1-gcc-4.6.2.tar.bz2}
+archive=${1-gcc-4.6.3.tar.bz2}
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 #export SHELL=$DJDIR/bin/sh.exe
@@ -91,8 +91,9 @@ rm -rf $gcc_dir/libffi
 rm -rf $gcc_dir/libjava
 rm -rf $gcc_dir/libchill
 rm -rf $gcc_dir/zlib
-#rm -rf $gcc_dir/libssp
 rm -rf $gcc_dir/libgomp
+rm -rf $gcc_dir/libgo
+rm -rf $gcc_dir/gcc/go
 rm -rf $gcc_dir/gcc/java
 rm -rf $gcc_dir/gcc/testsuite
 rm -rf $gcc_dir/gcc/treelang
